codyna-package: The 'codyna' Package.

codyna-packageR Documentation

The codyna Package.

Description

Performs analysis of complex dynamic systems with a focus on the temporal unfolding of patterns, changes, and state transitions in behavioral data. The package supports both time series and sequence data and provides tools for the analysis and visualization of complexity, pattern identification, trends, regimes, sequence typology as well as early warning signals.

Author(s)

Santtu Tikka and Mohammed Saqr

See Also

Useful links:


codyna documentation built on Jan. 16, 2026, 5:15 p.m.