ema: Ecological Momentary Assessment (EMA) Data

emaR Documentation

Ecological Momentary Assessment (EMA) Data

Description

Example data for complex adaptive systems perspective to behavior change research. The dataset consists of 20 individuals with 9 self-report variables (and time of response) each. For more information on the data, please see https://heinonmatti.github.io/complexity-behchange/dataset-info.html

Usage

ema

Format

A data.frame object.

https://github.com/heinonmatti/complexity-behchange


codyna documentation built on Jan. 16, 2026, 5:15 p.m.