sequence_indices: Compute Sequence Indices for Sequence Data

View source: R/indices.R

sequence_indicesR Documentation

Compute Sequence Indices for Sequence Data

Description

Compute Sequence Indices for Sequence Data

Usage

sequence_indices(data, cols, favorable, omega = 1)

Arguments

data

[data.frame, matrix, stslist]
Sequence data in wide format (rows are sequences, columns are time points).

cols

[expression]
A tidy selection of columns that should be considered as sequence data. By default, all columns are used.

favorable

[character()]
Names of states that should be considered as favorable states.

omega

[numeric(1)]
Omega parameter value used to compute the integrative potential.

Value

A tibble containing the index values.

Examples

sequence_indices(engagement)


codyna documentation built on Jan. 16, 2026, 5:15 p.m.