| codyna-package | R Documentation |
codyna Package.Performs analysis of complex dynamic systems with a focus on the temporal unfolding of patterns, changes, and state transitions in behavioral data. The package supports both time series and sequence data and provides tools for the analysis and visualization of complexity, pattern identification, trends, regimes, sequence typology as well as early warning signals.
Santtu Tikka and Mohammed Saqr
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.