Learn R Programming

codyna (version 0.1.0)

codyna-package: The codyna Package.

Description

Performs analysis of complex dynamic systems with a focus on the temporal unfolding of patterns, changes, and state transitions in behavioral data. The package supports both time series and sequence data and provides tools for the analysis and visualization of complexity, pattern identification, trends, regimes, sequence typology as well as early warning signals.

Arguments

Author

Santtu Tikka and Mohammed Saqr

See Also