| ema | R Documentation |
Example data for complex adaptive systems perspective to behavior change research. The dataset consists of 20 individuals with 9 self-report variables (and time of response) each. For more information on the data, please see https://heinonmatti.github.io/complexity-behchange/dataset-info.html
ema
A data.frame object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.